@@ -3,12 +3,14 @@ test_that("dataone library loads", {
 	expect_true(require(dataone))
 })
 test_that("MNode constructors", {
+  if(servicesDown) skip_on_cran()
 	library(dataone)
 	mn_uri <- "https://knb.ecoinformatics.org/knb/d1/mn/v2"
 	mn <- MNode(mn_uri)
 	expect_match(mn@endpoint, mn_uri)
 })
 test_that("MNode getCapabilities()", {
+  if(servicesDown) skip_on_cran()
 	library(dataone)
 	library(XML)
 	#mn_uri <- "https://knb.ecoinformatics.org/knb/d1/mn/v2"
@@ -19,6 +21,7 @@ test_that("MNode getCapabilities()", {
 	expect_match(mnKNB@identifier, "urn:node")
 })
 test_that("MNode getObject(), getChecksum()", {
+  if(servicesDown) skip_on_cran()
     library(dataone)
     #mn_uri <- "https://knb.ecoinformatics.org/knb/d1/mn/v2"
     #mn <- MNode(mn_uri)
@@ -44,6 +47,7 @@ test_that("MNode getObject(), getChecksum()", {
     expect_false(is.null(chksum))
 })
 test_that("MNode getSystemMetadata()", {
+  if(servicesDown) skip_on_cran()
     library(dataone)
     #mn <- getMNode(cnProd, "urn:node:KNB")
     pid <- "doi:10.5063/F1QN64NZ"
@@ -97,6 +101,7 @@ test_that("MNode generateIdentifier() on API v1 node", {
 })
 
 test_that("MNode describeObject()", {
+  if(servicesDown) skip_on_cran()
   library(dataone)
   #mn_uri <- "https://knb.ecoinformatics.org/knb/d1/mn/v2"
   #mn <- MNode(mn_uri)
@@ -226,7 +231,7 @@ test_that("MNode createObject(), updateObject(), archive()", {
       expect_match(response, newid)
       newsysmeta <- getSystemMetadata(mnTest, newid)
       expect_match(class(newsysmeta)[1], "SystemMetadata")
-      expect_that(newsysmeta@archived, is_true())
+      expect_that(newsysmeta@archived, expect_true())
     } else {
       skip("This test requires valid authentication.")
     }
